@@ -22,13 +22,13 @@ function loadConfig () {
     global $backuphost, $backupuser, $backupconf, $backupcron,
            $ssh_options, $logfile, $nonhttps, $smarty_templ, $smarty_compile ; 
 
-    @include_once ("/etc/slbackup/config.php") ; 
+    @include_once ("/etc/slbackup-php/config.php") ;
 
     if (empty ($nonhttps))       $nonhttps       = $_COOKIE ['nonhttps'] ;
     if (empty ($smarty_templ))   $smarty_templ   = $_COOKIE ['smarty_templ'] ;
     if (empty ($smarty_compile)) $smarty_compile = $_COOKIE ['smarty_compile'] ;
 
-    if (empty ($backuphost)) $backuphost="backup" ; 
+    if (empty ($backuphost)) $backuphost="localhost" ;
     if (empty ($backupuser)) $backupuser="root" ; 
     if (empty ($backupconf)) $backupconf="/etc/slbackup/slbackup.conf" ; 
     if (empty ($backupcron)) $backupcron="/etc/cron.d/slbackup" ; 
