@@ -561,15 +561,15 @@ global $backuphost, $backupuser, $logfile, $ssh_options, $ssh_askpass ;
 	        $log["start"] = strtotime($timestamp) ; 
 	    elseif ($info == "Finished slbackup.")
 	        $log["end"] = strtotime($timestamp) ; 
-	    elseif (strpos ($line, "Starting backup of client") !== false) {
+	    elseif (strpos ($line, "Starting backup of client ") !== false) {
 	        sscanf ($info, "Starting backup of client %s", $client) ; 
 	        if (!empty ($client))
 	            $log["clients"][$client]["start"] = strtotime($timestamp) ; 
-	    } elseif (strpos ($line, "Failed backing up client") !== false) {
+	    } elseif (strpos ($line, "Failed backing up client ") !== false) {
 	        sscanf ($info, "Failed backing up client %s", $client) ; 
 	        if (!empty ($client))
 	            $log["clients"][$client]["failed"] = strtotime($timestamp) ; 
-	    } elseif (strpos ($line, "Successfully finished backing up client") !== false) {
+	    } elseif (strpos ($line, "Successfully finished backing up client ") !== false) {
 	        sscanf ($info, "Successfully finished backing up client %s", $client) ; 
 	        if (!empty ($client))
 	            $log["clients"][$client]["ok"] = strtotime($timestamp) ; 
@@ -711,8 +711,8 @@ foreach ($scheduler as $line) {
         continue ; 
     $config["active"] = true ; 
     $array = explode (" ", $line) ; 
-    sscanf ($array[0], "%d", $config["minutes"]) ; 
-    sscanf ($array[1], "%d", $config["hours"]) ; 
+    sscanf ($array[0], "%s", $config["minutes"]) ;
+    sscanf ($array[1], "%s", $config["hours"]) ;
 }
 unset ($revisions) ; 
 
